pitchtools.get_numbered_chromatic_pitch_class_from_pitch_carrier
================================================================

.. autofunction:: abjad.tools.pitchtools.get_numbered_chromatic_pitch_class_from_pitch_carrier.get_numbered_chromatic_pitch_class_from_pitch_carrier
